From: Bernd Waibel <waebbl-gentoo@posteo.net>
Date: Sat, 30 Oct 2021 11:56:04 +0200
Subject: [PATCH] find (py)ilmbase in config mode

Signed-off-by: Bernd Waibel <waebbl-gentoo@posteo.net>

diff --git a/cmake/AlembicIlmBase.cmake b/cmake/AlembicIlmBase.cmake
index 9f52ca6..f076e14 100644
--- a/cmake/AlembicIlmBase.cmake
+++ b/cmake/AlembicIlmBase.cmake
@@ -43,23 +43,27 @@ IF (Imath_FOUND)
 ELSE()
     MESSAGE(STATUS "Could not find Imath looking for IlmBase instead.")
     # What we really want to do is look for libs Imath and half
-    FIND_PACKAGE(IlmBase)
+    FIND_PACKAGE(IlmBase CONFIG REQUIRED)
     SET(ALEMBIC_USING_IMATH_3 OFF)
+    SET(ILMBASE_FOUND True)
+    GET_TARGET_PROPERTY(ALEMBIC_ILMBASE_INCLUDE_DIRECTORY IlmBase::IlmBaseConfig INTERFACE_INCLUDE_DIRECTORIES)
+    SET(ALEMBIC_ILMBASE_HALF_LIB IlmBase::Half)
+    SET(ALEMBIC_ILMBASE_IEX_LIB IlmBase::Iex)
+    SET(ALEMBIC_ILMBASE_IEXMATH_LIB IlmBase::IexMath)
+    SET(ALEMBIC_ILMBASE_ILMTHREAD_LIB IlmBase::IlmThread)
+    SET(ALEMBIC_ILMBASE_IMATH_LIB IlmBase::Imath)
+    SET(ALEMBIC_ILMBASE_LIBS ${ALEMBIC_ILMBASE_HALF_LIB} ${ALEMBIC_ILMBASE_IEX_LIB} ${ALEMBIC_ILMBASE_IEXMATH_LIB}
+        ${ALEMBIC_ILMBASE_ILMTHREAD_LIB} ${ALEMBIC_ILMBASE_IMATH_LIB})
 
     IF (ILMBASE_FOUND)
         SET(ALEMBIC_ILMBASE_FOUND 1 CACHE STRING "Set to 1 if IlmBase is found, 0 otherwise")
-
-        SET(ALEMBIC_ILMBASE_LIBS
-            ${ALEMBIC_ILMBASE_IMATH_LIB}
-            ${ALEMBIC_ILMBASE_ILMTHREAD_LIB}
-            ${ALEMBIC_ILMBASE_IEX_LIB}
-            ${ALEMBIC_ILMBASE_HALF_LIB}
-        )
-
-        if (${ALEMBIC_ILMBASE_IEXMATH_LIB})
-            SET(ALEMBIC_ILMBASE_LIBS ${ALEMBIC_ILMBASE_LIBS} ${ALEMBIC_ILMBASE_IEXMATH_LIB})
-        endif (${ALEMBIC_ILMBASE_IEXMATH_LIB})
-
+        MESSAGE(STATUS "Found package IlmBase")
+        MESSAGE( STATUS "ILMBASE INCLUDE PATH: ${ALEMBIC_ILMBASE_INCLUDE_DIRECTORY}" )
+        MESSAGE( STATUS "HALF LIB: ${ALEMBIC_ILMBASE_HALF_LIB}" )
+        MESSAGE( STATUS "IEX LIB: ${ALEMBIC_ILMBASE_IEX_LIB}" )
+        MESSAGE( STATUS "IEXMATH LIB: ${ALEMBIC_ILMBASE_IEXMATH_LIB}" )
+        MESSAGE( STATUS "ILMTHREAD LIB: ${ALEMBIC_ILMBASE_ILMTHREAD_LIB}" )
+        MESSAGE( STATUS "IMATH LIB: ${ALEMBIC_ILMBASE_IMATH_LIB}" )
     ELSE()
         SET(ALEMBIC_ILMBASE_FOUND 0 CACHE STRING "Set to 1 if IlmBase is found, 0 otherwise")
     ENDIF()
diff --git a/cmake/AlembicPyIlmBase.cmake b/cmake/AlembicPyIlmBase.cmake
index 249e084..3cc6253 100644
--- a/cmake/AlembicPyIlmBase.cmake
+++ b/cmake/AlembicPyIlmBase.cmake
@@ -43,20 +43,19 @@ IF (Imath_FOUND)
     SET(ALEMBIC_PYILMBASE_PYIMATH_LIB Imath::PyImath_Python${PYTHON_VERSION_MAJOR}_${PYTHON_VERSION_MINOR})
     MESSAGE(STATUS "Found package Imath using: ${ALEMBIC_PYILMBASE_PYIMATH_LIB}")
 ELSE()
-    FIND_PACKAGE(PyIlmBase)
+	MESSAGE(STATUS "Could not find Imath looking for PyIlmBase instead.")
+    FIND_PACKAGE(PyIlmBase CONFIG REQUIRED)
+    SET(PYILMBASE_FOUND True)
     IF (PYILMBASE_FOUND)
         SET(ALEMBIC_PYILMBASE_FOUND 1 CACHE STRING "Set to 1 if PyIlmBase is found, 0 otherwise")
-
-        SET(ALEMBIC_PYILMBASE_LIBS
-            ${ALEMBIC_PYILMBASE_PYIMATH_LIB}
-        )
-
-        GET_FILENAME_COMPONENT(ALEMBIC_PYILMBASE_LIB_DIRECTORY
-            ${ALEMBIC_PYILMBASE_PYIMATH_LIB}
-            PATH
-        )
-
+        SET(ALEMBIC_PYILMBASE_PYIMATH_LIB PyIlmBase::PyImath_Python${PYTHON_VERSION_MAJOR}_${PYTHON_VERSION_MINOR})
+        MESSAGE(STATUS "Found package PyIlmBase using: ${ALEMBIC_PYILMBASE_PYIMATH_LIB}")
+        GET_TARGET_PROPERTY(ALEMBIC_PYILMBASE_INCLUDE_DIRECTORY PyIlmBase::PyImath_Python${PYTHON_VERSION_MAJOR}_${PYTHON_VERSION_MINOR} INTERFACE_INCLUDE_DIRECTORIES)
+        SET(ALEMBIC_PYIMATH_MODULE_DIRECTORY "/usr/lib/python${PYTHON_VERSION_MAJOR}.${PYTHON_VERSION_MINOR}/site-packages")
+        MESSAGE(STATUS "PYILMBASE INCLUDE PATH: ${ALEMBIC_PYILMBASE_INCLUDE_DIRECTORY}")
+        MESSAGE(STATUS "PYIMATH LIB: ${ALEMBIC_PYILMBASE_PYIMATH_LIB}")
+        MESSAGE(STATUS "PYIMATH MODULE: ${ALEMBIC_PYIMATH_MODULE_DIRECTORY}")
     ELSE()
         SET(ALEMBIC_PYILMBASE_FOUND 0 CACHE STRING "Set to 1 if PyIlmBase is found, 0 otherwise")
     ENDIF()
-ENDIF()
\ No newline at end of file
+ENDIF()
-- 
2.33.1
